@@ -3,6 +3,9 @@
 # email:yuyc@ishangqi.com
 # date:2022/2/17 2:45 下午
 # Copyright (C) 2022 The lesscode Team
+import pymysql
+from dbutils.pooled_db import PooledDB
+
 from lesscode.db.base_connection_pool import BaseConnectionPool
 import aiomysql
 
@@ -30,3 +33,8 @@ class MysqlPool(BaseConnectionPool):
             return pool
         else:
             raise NotImplementedError
+
+    def sync_create_pool(self):
+        pool = PooledDB(pymysql, 5, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
+                        passwd=self.conn_info.password, db=self.conn_info.db_name, charset="utf8", autocommit=True)
+        return pool
