@@ -97,7 +97,7 @@ class BaseHandler(RequestHandler):
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
             self.end_time = int(round(time.time() * 1000))
-            self.set_header("ApiTime", f"{self.end_time - self.start_time}ms")
+            self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
@@ -186,7 +186,7 @@ class BaseHandler(RequestHandler):
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
             self.end_time = int(round(time.time() * 1000))
-            self.set_header("ApiTime", f"{self.end_time - self.start_time}ms")
+            self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
@@ -202,8 +202,8 @@ class BaseHandler(RequestHandler):
             self.set_header("Access-Control-Allow-Origin", origin)
         else:
             self.set_header("Access-Control-Allow-Origin", "*")
-        self.set_header("requestID", self.request.headers.get("requestID", ""))
-        self.set_header("pluginRunningTime", self.request.headers.get("pluginRunningTime", ""))
+        self.set_header("Request-Id", self.request.headers.get("Request-Id", ""))
+        self.set_header("Plugin-Running-Time", self.request.headers.get("Plugin-Running-Time", ""))
         self.set_header("Access-Control-Allow-Headers", "x-requested-with,Authorization,Can-read-cache")
         self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
         self.set_header("Access-Control-Expose-Headers", "Access-Token")
@@ -248,10 +248,10 @@ class BaseHandler(RequestHandler):
         获取当前用户信息
         :return:
         """
-        user_info_json = self.request.headers.get("userInfo")
-        if user_info_json:
+        user_json = self.request.headers.get("User")
+        if user_json:
             # TODO 未做加密
-            user_info = json.loads(user_info_json)
+            user_info = json.loads(user_json)
             user = User()
             for key in user_info:
                 setattr(user, key, user_info[key])
