@@ -6,10 +6,15 @@
 
 import threading
 
+import tornado.options
 from tornado.web import RequestHandler
 
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
+from tornado.options import define
+
+define("route_prefix", default="", type=str, help="路由前缀")
+tornado.options.options.route_prefix = ""
 
 
 class RouterMapping(list):
@@ -39,9 +44,11 @@ class RouterMapping(list):
 def Handler(url: str):
     """
     RequestHandler对应路径注册装饰器，完成处理类与url对应注册。
+    :param prefix: 路由前缀
     :param url:
     :return:
     """
+    route_prefix = tornado.options.options.route_prefix
 
     def wrapper(cls):
         # 验证是否为RequestHandler 子类，仅注册其子类
@@ -54,7 +61,7 @@ def Handler(url: str):
             # 处理类 RequestHandler 子类 使用时统一继承BaseHandler
             handler = item[1]
             # 全路径 Handler+Mapping 组合
-            full_url = url + item[2]
+            full_url = route_prefix + url + item[2]
             # 判断是否存在重复注册情况，重复情况直接抛出异常
             if [router for router in RouterMapping.instance() if full_url in router]:
                 raise BusinessException(StatusCode.RESOURCE_EXIST(f'路由"{full_url}"'))
